/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * KibaPluginLoader handles the loading od KibaPlugin's.
 **/

#ifndef __KIBA_PLUGIN_LOADER_H__
#define __KIBA_PLUGIN_LOADER_H__

#include <gtk/gtk.h>
#include <glib-object.h>
#include <gdk/gdk.h>
#include <glib.h>

#include <kiba-prefs.h>
#include <kiba-plugin.h>

G_BEGIN_DECLS

typedef struct _KibaPluginLoader KibaPluginLoader;
typedef struct _KibaPluginLoaderClass KibaPluginLoaderClass;

typedef struct _KibaPluginService KibaPluginService;

#define KIBA_TYPE_PLUGIN_LOADER           (kiba_plugin_loader_get_type ())
#define KIBA_PLUGIN_LOADER(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_PLUGIN_LOADER, KibaPluginLoader))
#define KIBA_PLUGIN_LOADER_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_PLUGIN_LOADER,  KibaPluginLoaderClass))
#define KIBA_IS_PLUGIN_LOADER(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_PLUGIN_LOADER))
#define KIBA_IS_PLUGIN_LOADER_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_PLUGIN_LOADER))
#define KIBA_PLUGIN_LOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_PLUGIN_LOADER, KibaPluginLoaderClass))

typedef struct {
	char *path;
	KibaPluginType type;
}KibaPluginLoaderPluginData;

/**
 * A PluginLoader Handle.
 */
struct _KibaPluginLoader {
	GObject parent_instance;
};

struct _KibaPluginLoaderClass {
	GObjectClass parent_class;
	
	void (* service_registered) (KibaPluginLoader *loader, KibaPluginService *service);
	void (* service_unregistered) (KibaPluginLoader *loader, KibaPluginService *service);
};

KibaPluginLoader* kiba_plugin_loader_get (void);

void kiba_plugin_loader_for_all_plugins (KibaPluginLoader *loader,
                                         GFunc for_all_func,
                                         void  *data);

GList* kiba_plugin_loader_get_plugins (KibaPluginLoader *loader);

GList* kiba_plugin_loader_get_plugin_paths (KibaPluginLoader *loader);

gboolean kiba_plugin_loader_initiall_plugins_at_path (KibaPluginLoader *loader,
                                                      KibaPluginType type,
                                                      const char *plugin_path);

KibaPlugin* kiba_plugin_loader_new_plugin (KibaPluginLoader *loader,
                                           const char *pluginPath);

gboolean  kiba_plugin_loader_load_plugin (KibaPluginLoader *loader,
                                          KibaPlugin *plugin);

void kiba_plugin_loader_unload_plugin (KibaPluginLoader *loader,
                                       KibaPlugin *plugin);

void kiba_plugin_loader_popup_dependency_dialog (KibaPlugin *plugin,
                                                 GList *dependencies,
                                                 KibaPrefsFile *configFile);

void kiba_plugin_loader_popup_depend_on_dialog (KibaPlugin *plugin,
                                                GList *dependencies,
                                                KibaPrefsFile *file);

KibaPluginService* kiba_plugin_loader_get_service (KibaPluginLoader *loader,
                                                   KibaPlugin *request_plugin,
                                                   const char *serviceID);

gboolean kiba_plugin_loader_invoke_service (KibaPluginLoader *loader,
                                            KibaPluginService *service,
                                            GValueArray *value_array);

G_END_DECLS

#endif
