/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_TRIANGLE_H__
#define __KIBA_TRIANGLE_H__

#include <glib.h>
#include <cairo.h>

#include <kiba-cairo-utils.h>

G_BEGIN_DECLS

typedef struct _KibaTriangle         KibaTriangle;
typedef struct _KibaTriangleClass    KibaTriangleClass;

#define KIBA_TYPE_TRIANGLE           (kiba_triangle_get_type ())
#define KIBA_TRIANGLE(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_TRIANGLE, KibaTriangle))
#define KIBA_TRIANGLE_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_TRIANGLE,  KibaTriangleClass))
#define KIBA_IS_TRIANGLE(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_TRIANGLE))
#define KIBA_IS_TRIANGLE_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_TRIANGLE))
#define KIBA_TRIANGLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_TRIANGLE, KibaTriangleClass))

#define TRIANGLE_ICON_SIZE    28

/**
 * Triangle flags.
 **/
enum {
	KIBA_TRIANGLE_DRAWABLE = 0
};

struct _KibaTriangle {
	GObject          parent;
	
	GtkWidget       *win;       /**< Pointer to the default KibaWin instance */
	
	cairo_surface_t *surface;   /**< The triangle surface */
	gint             flags;     /**< The triangle flags */
};

struct _KibaTriangleClass {
	GObjectClass parent_class;
};

KibaTriangle* kiba_triangle_new (GtkWidget *widget);

void kiba_triangle_add_widget (KibaTriangle *triangle,
				    GtkWidget    *widget);

void kiba_triangle_remove_widget (KibaTriangle *triangle,
				    GtkWidget    *widget);

void kiba_triangle_set_icon (KibaTriangle *triangle,
			     const char   *icon);

void kiba_triangle_set_flag (KibaTriangle *triangle,
			      gint          flag);

void kiba_triangle_unset_flag (KibaTriangle *triangle,
			       gint          flag);

void kiba_triangle_draw (KibaTriangle         *triangle,
			 const KibaLayoutData *d,
			 cairo_t              *cr);

void kiba_triangle_destroy (KibaTriangle *triangle);


G_END_DECLS

#endif
