/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_WIN_H__
#define __KIBA_WIN_H__

#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <cairo.h>

#include <kiba-dock.h>
#include <kiba-triangle.h>
#include <kiba-progress.h>
#include <kiba-types.h>

G_BEGIN_DECLS

#define KIBA_TYPE_WIN           (kiba_win_get_type ())
#define KIBA_WIN(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_WIN, KibaWin))
#define KIBA_WIN_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_WIN,  KibaWinClass))
#define KIBA_IS_WIN(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_WIN))
#define KIBA_IS_WIN_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_WIN))
#define KIBA_WIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_WIN, KibaWinClass))

#define KIBA_WIN_CHILD(win)      gtk_bin_get_child(GTK_BIN(win))

/* property macros */
#define KIBA_WIN_IS_ABOVE(win) GET_FLAG(win->probs, KIBA_WIN_ABOVE)
#define KIBA_WIN_IS_BELOW(win) GET_FLAG(win->probs, KIBA_WIN_BELOW)

typedef struct _KibaWin KibaWin;
typedef struct _KibaWinClass KibaWinClass;

/**
 * KibaDragReceiveFunc:
 * @Param1: The drag and drop Context.
 * @Param2: The group.
 * @Param3: User data.
 *
 * Callback function to handle drag and drag receive events.
 *
 * Returns: TRUE on succes, otherwhise FALSE
 */
typedef gboolean (*KibaDragReceiveFunc) (GdkDragContext*, const char*, gpointer);

/**
 * KibaDragDestFunc:
 * @Param1: The drag and drop context.
 * @Param2: The group.
 * @Param3: User data.
 * @Param4: The drag action return.
 * @Param5: The drag Icon return.
 *
 * Callback function to check if a drag and drop receive is possible.
 * If multiple KibaDragReceiveFunc's can handle the drag,
 * a menu is created to allow the user choosing the drag action
 */
typedef void (*KibaDragDestFunc) (GdkDragContext*, const char*, gpointer, char**, char**);

typedef void (*KibaWinAllocateChildrenFunc) (KibaWin*, gpointer);

typedef enum {
	KIBA_WIN_BELOW = 0, /**< keep the window below */
	KIBA_WIN_ABOVE     /**< keep the window above */
}KibaWinProbs;

struct _KibaWin {
	GtkWindow window;
	
	KibaWinProbs probs; /**< The window propertys */
	
	KibaWinAllocateChildrenFunc allocate_children;
	gpointer allocate_data;
	
	KibaTriangle *triangle; /**< the KibaTriangle instance */
	KibaProgress *progress; /**< the KibaProgress instance */
};

struct _KibaWinClass {
	GtkWindowClass  parent_class;
	
	/* signals */
	void (* dock_hidden) (KibaWin  *win,
                          KibaDock *dock);
	void (* dock_unhidden) (KibaWin  *win,
                            KibaDock *dock);
};

GtkWidget* kiba_win_new (void);

cairo_t* kiba_win_cairo_create (KibaWin *win);

void kiba_win_invalidate_area (GtkWidget *widget,
                               GdkRectangle area);

gboolean kiba_win_set_children_allocate_func (KibaWin *win,
                                          KibaWinAllocateChildrenFunc fun,
                                          gpointer data);

gboolean kiba_win_unset_children_allocate_func (KibaWin *win,
                                            KibaWinAllocateChildrenFunc fun);

void kiba_win_set_flag (KibaWin *win,
                        KibaWinProbs prob);

void kiba_win_unset_flag (KibaWin *win,
                          KibaWinProbs prob);

void kiba_win_add_drag_func (KibaWin *win,
                             KibaDragReceiveFunc receive_func,
                             KibaDragDestFunc dest_func,
                             gpointer user_data);

void kiba_win_remove_drag_func (KibaWin *win,
                                KibaDragReceiveFunc receive_func);

G_END_DECLS

#endif
